@@ -48,17 +48,14 @@ class SweepScreen(module_base.ModuleScreen):
 
         self.combo_excitation_method = nsf.gui.NSFComboBox(ComboExcitationMethods, "Excitation Method")
 
-        self.label_input_source = QtWidgets.QLabel("Input Source")
-        self.combo_input_source = QtWidgets.QComboBox()
-        self.combo_input_source.addItems(freq_sweep.FrequencySweep.input_sources_names.values())
+        self.combo_input_source_items =  nsf.gui.NSFComboBox.create_entry_list_from_dict(freq_sweep.FrequencySweep.input_sources_names)
+        self.combo_input_source = nsf.gui.NSFComboBox(self.combo_input_source_items , "Input Source")
 
-        self.label_output_source = QtWidgets.QLabel("Output Source")
-        self.combo_output_source = QtWidgets.QComboBox()
-        self.combo_output_source.addItems(freq_sweep.FrequencySweep.output_names.values())
-
-        self.label_bandwidth = QtWidgets.QLabel("Bandwidth")
-        self.combo_bandwidth = QtWidgets.QComboBox()
-        self.combo_bandwidth.addItems(freq_sweep.FrequencySweep.bandwidths_names.values())
+        self.combo_output_source_items =  nsf.gui.NSFComboBox.create_entry_list_from_dict(freq_sweep.FrequencySweep.output_names)
+        self.combo_output_source = nsf.gui.NSFComboBox(self.combo_output_source_items , "Output Source")
+     
+        self.combo_bandwidth_items =  nsf.gui.NSFComboBox.create_entry_list_from_dict(freq_sweep.FrequencySweep.bandwidths_names)
+        self.combo_bandwidth = nsf.gui.NSFComboBox(self.combo_bandwidth_items , "Bandwidth")
 
         self.scival_center_frequency = nsf.gui.NSFSciEdit("Center Frequency")
         self.scival_center_frequency.set_allowed_prefix_ids(allowed_frequency_units)
@@ -90,16 +87,12 @@ class SweepScreen(module_base.ModuleScreen):
         self.button_start_stop = QtWidgets.QPushButton("Start Sweep")
         self.button_save = QtWidgets.QPushButton("Save")
         
-
         self.layout_left = QtWidgets.QVBoxLayout()
         self.layout_left.addWidget(self.label_cantilever)
         self.layout_left.addWidget(self.combo_cantilever)
         self.layout_left.addWidget(self.combo_excitation_method)
-        self.layout_left.addWidget(self.label_input_source)
         self.layout_left.addWidget(self.combo_input_source)
-        self.layout_left.addWidget(self.label_output_source)
         self.layout_left.addWidget(self.combo_output_source)
-        self.layout_left.addWidget(self.label_bandwidth)
         self.layout_left.addWidget(self.combo_bandwidth)
         self.layout_left.addWidget(self.scival_center_frequency)
         self.layout_left.addWidget(self.scival_frequency_range)
@@ -148,6 +141,9 @@ class SweepScreen(module_base.ModuleScreen):
         # binding ProVal to widgets ensure that they are alway in sync 
         nsf.gui.connect_to_property(self.combo_plot_style, self.module.settings.plot_style_id)
         nsf.gui.connect_to_property(self.combo_excitation_method, self.module.settings.excitation_method)
+        nsf.gui.connect_to_property(self.combo_input_source, self.module.settings.input_source)
+        nsf.gui.connect_to_property(self.combo_output_source, self.module.settings.output_source)
+        nsf.gui.connect_to_property(self.combo_bandwidth, self.module.settings.bandwidth)
         nsf.gui.connect_to_property(self.scival_center_frequency, self.module.settings.center_frequency)
         nsf.gui.connect_to_property(self.scival_frequency_range, self.module.settings.frequency_range)
         nsf.gui.connect_to_property(self.scival_frequency_steps, self.module.settings.frequency_steps)
@@ -155,10 +151,6 @@ class SweepScreen(module_base.ModuleScreen):
         
         # combo boxes have to be connected separately
         self.combo_cantilever.activated.connect(self.update_cantilever)
-        self.combo_input_source.activated.connect(self.update_input_source)
-        self.combo_output_source.activated.connect(self.update_output_source)
-        self.combo_bandwidth.activated.connect(self.update_bandwidth)
-
         self.combo_plot_style.value_changed_event.connect(self.update_plot)
 
         # buttons have to be connected separately  
@@ -275,15 +267,3 @@ class SweepScreen(module_base.ModuleScreen):
     def update_excitation_method(self):
         excitation_method = self.combo_excitation_method.value()
         self.module.select_excitation_method(excitation_method)
-
-    def update_input_source(self):
-        channel_name = self.combo_input_source.currentText()
-        self.module.select_input_source(channel_name)
-
-    def update_output_source(self):
-        channel_name = self.combo_output_source.currentText()
-        self.module.select_output_source(channel_name)
-
-    def update_bandwidth(self):
-        channel_name = self.combo_bandwidth.currentText()
-        self.module.select_bandwidth(channel_name)
\ No newline at end of file
