@@ -71,6 +71,7 @@ class SwitchingSpecScreen(module_base.ModuleScreen):
         self.scival_file_index.set_value_min_max(1, 10000)
 
         self.check_show_on_data = QtWidgets.QCheckBox("Show 'on' data")
+        self.check_do_revers_ramp = QtWidgets.QCheckBox("Backward first")
 
         self.edit_file_mask = nsf.gui.NSFEdit("File name mask")
         self.edit_file_path = nsf.gui.NSFEdit("Destination path")
@@ -87,6 +88,8 @@ class SwitchingSpecScreen(module_base.ModuleScreen):
         self.layout_left.addWidget(self.scival_num_steps)
         self.layout_left.addWidget(self.scival_time_delay)
         self.layout_left.addSpacing(10)
+        self.layout_left.addWidget(self.check_do_revers_ramp)
+        self.layout_left.addSpacing(10)
         self.layout_left.addWidget(self.check_show_on_data)
         self.layout_left.addStretch()
         self.layout_left.addWidget(self.button_start_stop)
@@ -142,7 +145,7 @@ class SwitchingSpecScreen(module_base.ModuleScreen):
         nsf.gui.connect_to_property(self.edit_file_mask, self.module.settings.file_name_mask)
         nsf.gui.connect_to_property(self.scival_file_index, self.module.settings.file_index)
         nsf.gui.connect_to_property(self.check_auto_save, self.module.settings.auto_save_data)
-        nsf.gui.connect_to_property(self.check_show_on_data, self.module.settings.show_on_data_values)
+        nsf.gui.connect_to_property(self.check_do_revers_ramp, self.module.settings.revers_ramp)
 
         # buttons have to be connected separately
         self.button_start_stop.clicked.connect(self.on_button_start_stop_clicked)    
@@ -210,6 +213,7 @@ class SwitchingSpecScreen(module_base.ModuleScreen):
         self.scival_output_center.setEnabled(enabled)
         self.scival_num_steps.setEnabled(enabled)
         self.scival_time_delay.setEnabled(enabled)
+        self.check_do_revers_ramp.setEnabled(enabled)
 
     def start_stop_button_state(self, wait: bool = False, stop_state: bool = False):
         if wait:
