@@ -50,6 +50,7 @@ class SwitchingSpecModule(module_base.ModuleBase):
         self.settings.number_of_steps.sig_value_changed.connect(self.update_worker_parameter)
         self.settings.time_delay_after_step.sig_value_changed.connect(self.update_worker_parameter)
         self.settings.output_id.sig_value_changed.connect(self.update_worker_parameter)
+        self.settings.revers_ramp.sig_value_changed.connect(self.update_worker_parameter)
 
     def setup_worker_thread(self):
         """ Create the background worker task and connect to its event """
@@ -85,7 +86,10 @@ class SwitchingSpecModule(module_base.ModuleBase):
 
     def update_worker_parameter(self):
         self.worker_thread.par_output_id = self.settings.output_id.value
-        self.worker_thread.par_output_span = self.settings.output_span.value
+        if self.settings.revers_ramp.value:
+            self.worker_thread.par_output_span = -1.0 * self.settings.output_span.value
+        else:
+            self.worker_thread.par_output_span = self.settings.output_span.value
         self.worker_thread.par_output_center = self.settings.output_center.value
         self.worker_thread.par_time_per_step = self.settings.time_delay_after_step.value
         self.worker_thread.par_steps = self.settings.number_of_steps.value
