@@ -4,22 +4,25 @@ License - MIT
 """
 
 from PySide2 import QtWidgets
-import nanosurf.lib.datatypes.sci_val as sci_val
-from nanosurf.lib.gui import nsf_sci_edit, nsf_tables, nsf_plots, bind_gui
-from app import module_base
-from app import app_gui
+import nanosurf as nsf
+from app import module_base, app_gui
 from modules.demo_module import module, settings
 
-class ResultTableID(nsf_tables.TableEntryIDs):
+class ResultTableID(nsf.gui.nsf_tables.TableEntryIDs):
     """ identifier id are used in a nsf_table widget"""
     Items = 0
     last_data = 1
     mean_value = 2
 
-""" some usefull list of allowed prefixes used by nsf_sci_edit widgets"""
-allowed_count_units = [sci_val.up.Prefix.base]
-allowed_time_units = [sci_val.up.Prefix.base, sci_val.up.Prefix.milli]
-allowed_meter_units = [sci_val.up.Prefix.milli, sci_val.up.Prefix.micro, sci_val.up.Prefix.nano]
+ComboPlotStyles = [
+    nsf.gui.NSFComboEntry(settings.PlotStyleID.PlotSin,'Sin-Plot'),
+    nsf.gui.NSFComboEntry(settings.PlotStyleID.PlotCos,'Cos-Plot'),
+]
+
+""" some useful list of allowed prefixes used by nsf_sci_edit widgets"""
+allowed_count_units = [nsf.sci_val.up.Prefix.base]
+allowed_time_units = [nsf.sci_val.up.Prefix.base, nsf.sci_val.up.Prefix.milli]
+allowed_meter_units = [nsf.sci_val.up.Prefix.milli, nsf.sci_val.up.Prefix.micro, nsf.sci_val.up.Prefix.nano]
 
 class DemoScreen(module_base.ModuleScreen):
     def __init__(self):
@@ -31,15 +34,15 @@ class DemoScreen(module_base.ModuleScreen):
 
         # left layout - main controls ------------------------------------------------------------
 
-        self.scival_repetitions = nsf_sci_edit.NSFSciEdit("Repetitions")
+        self.scival_repetitions = nsf.gui.NSFSciEdit("Repetitions")
         self.scival_repetitions.set_allowed_prefix_ids(allowed_count_units)
-        self.scival_repetitions.set_prefix_id(sci_val.up.Prefix.base)
+        self.scival_repetitions.set_prefix_id(nsf.sci_val.up.Prefix.base)
         self.scival_repetitions.set_precision(0)
         self.scival_repetitions.set_value_min_max(1, 1000)
 
-        self.scival_time_per_rep = nsf_sci_edit.NSFSciEdit("Time per Repetition")
+        self.scival_time_per_rep = nsf.gui.NSFSciEdit("Time per Repetition")
         self.scival_time_per_rep.set_allowed_prefix_ids(allowed_time_units)
-        self.scival_time_per_rep.set_prefix_id(sci_val.up.Prefix.base)
+        self.scival_time_per_rep.set_prefix_id(nsf.sci_val.up.Prefix.base)
         self.scival_time_per_rep.set_precision(2)
         self.scival_time_per_rep.set_value_min_max(0.01, 10.0)
         
@@ -55,9 +58,9 @@ class DemoScreen(module_base.ModuleScreen):
         self.layout_left.addWidget(self.button_start_stop)
 
         # mid layout - plots and result ---------------------------------------------------------
-        self.chart_plot = nsf_plots.NSFChart(logmodex=False)
+        self.chart_plot = nsf.gui.NSFChart(logmodex=False)
 
-        self.tableResults = nsf_tables.NSFNameValueTable(ResultTableID)
+        self.tableResults = nsf.gui.NSFNameValueTable(ResultTableID)
         self.tableResults.define_entry(ResultTableID.Items,"Items")
         self.tableResults.define_entry(ResultTableID.last_data,"Last Data")
         self.tableResults.define_entry(ResultTableID.mean_value,"Mean Value")
@@ -67,12 +70,9 @@ class DemoScreen(module_base.ModuleScreen):
         self.layout_mid.addWidget(self.tableResults)
 
         # right layout - additional user inputs
-        self.label_plot_style = QtWidgets.QLabel("Plot Style")
-        self.combo_plot_style = QtWidgets.QComboBox()
-        self.combo_plot_style.addItems(settings.PlotStyleNames)
+        self.combo_plot_style = nsf.gui.NSFComboBox(ComboPlotStyles,"Plot Style")
         
         self.layout_right= QtWidgets.QVBoxLayout()
-        self.layout_right.addWidget(self.label_plot_style)
         self.layout_right.addWidget(self.combo_plot_style)
         self.layout_right.addSpacerItem(app_gui.StdVSpacer())
 
@@ -92,10 +92,10 @@ class DemoScreen(module_base.ModuleScreen):
         """ connect all gui widgets to module settings or any other source """
         
         # binding ProVal to widgets ensure that they are alway in sync 
-        bind_gui.connect_to_property(self.combo_plot_style, self.module.settings.plot_func_id)
-        bind_gui.connect_to_property(self.scival_repetitions, self.module.settings.repetitions)
-        bind_gui.connect_to_property(self.scival_time_per_rep, self.module.settings.time_per_repetition)
-        bind_gui.connect_to_property(self.check_emit_ticks, self.module.settings.send_ticks)
+        nsf.gui.connect_to_property(self.combo_plot_style, self.module.settings.plot_func_id)
+        nsf.gui.connect_to_property(self.scival_repetitions, self.module.settings.repetitions)
+        nsf.gui.connect_to_property(self.scival_time_per_rep, self.module.settings.time_per_repetition)
+        nsf.gui.connect_to_property(self.check_emit_ticks, self.module.settings.send_ticks)
 
         # buttons have to be connected separately
         self.button_start_stop.clicked.connect(self.on_button_start_stop_clicked)    
@@ -110,10 +110,10 @@ class DemoScreen(module_base.ModuleScreen):
 
     def init_plot(self):
         self.chart_plot.set_title(f"Measurements")
-        self.chart_plot.set_label(nsf_plots.NSFChart.Axis.bottom, "Index")
-        self.chart_plot.set_unit(nsf_plots.NSFChart.Axis.bottom, "")
-        self.chart_plot.set_label(nsf_plots.NSFChart.Axis.left, "Data")
-        self.chart_plot.set_unit(nsf_plots.NSFChart.Axis.left, "Arb")  
+        self.chart_plot.set_label(nsf.gui.NSFChart.Axis.bottom, "Index")
+        self.chart_plot.set_unit(nsf.gui.NSFChart.Axis.bottom, "")
+        self.chart_plot.set_label(nsf.gui.NSFChart.Axis.left, "Data")
+        self.chart_plot.set_unit(nsf.gui.NSFChart.Axis.left, "Arb")  
         self.chart_plot.plot.setXRange(0, self.module.settings.repetitions.value-1)
         # self.chart_plot.plot.vb.enableAutoRange(y=True)
         # self.chart_plot.plot.vb.setAutoVisible(y=False)
