@@ -1,4 +1,4 @@
-""" Some helpfull mathematical functions for analysing data in SciChannels and SciStreams
+""" Some helpful mathematical functions for analyzing data in SciChannels and SciStreams
 Copyright Nanosurf AG 2021
 License - MIT
 """
@@ -10,7 +10,10 @@ import statistics as stat
 import nanosurf.lib.datatypes.sci_channel as ch
 import nanosurf.lib.datatypes.sci_stream as ss
 
-g_unit_str_frq_spectral_density = r"/$\sqrt{Hz}$"
+g_use_matplotlib_format_for_unit_str = False
+
+def get_spectral_density_unit() -> str:
+    return r"/$\sqrt{Hz}$" if g_use_matplotlib_format_for_unit_str else r"\sqrt(Hz)"
 
 def find_peaks(stream: ss.SciStream, channel_index: int = 0, **kwargs) -> ss.SciStream:
     """ Find all peaks in a stream's channel. e.g amplitude peaks in a frq-spectrum.
@@ -36,7 +39,7 @@ def find_peaks(stream: ss.SciStream, channel_index: int = 0, **kwargs) -> ss.Sci
     result.channels[0] = ch.SciChannel(copy_from=max_y_array, unit=data_channel.unit)
     return result
 
-def find_highest_peak(stream: ss.SciStream, channel_index: int = 0, **kwargs) -> tuple:
+def find_highest_peak(stream: ss.SciStream, channel_index: int = 0, **kwargs) -> tuple[bool, float, float]:
     """ Returns the highest peak in a data channel.
     
     Returns
@@ -145,7 +148,7 @@ def calc_fft(data_samples: ch.SciChannel, samplerate: float, window: fft_window_
     result = ss.SciStream((fft_frequency_array, fft_result_array))
     result.x.unit = "Hz"
     if spectral_density:
-        result.channels[0].unit = f"{data_samples.unit}{g_unit_str_frq_spectral_density}"
+        result.channels[0].unit = f"{data_samples.unit}{get_spectral_density_unit()}"
     else:
         result.channels[0].unit = data_samples.unit
     if compress:
@@ -255,11 +258,11 @@ def get_total_harmonic_distortion(spec_data: ss.SciStream, channel_index: int =
     spec_data: SciStream
         The data source 
     channel_index: int
-        The data source  channel to analyse
+        The data source  channel to analyze
     fundamental_frequency
         the fundamental frequency from which the THD calculation shall be done. Defined in [Hz]. The nearest frq found in the frq_array is used 
     max_number_of_harmonics 
-        optional, limits the number of harmonic frequency to used for THD calculation, 0 defines to use all possible harmonics found in the spectrum
+        optional, limits the number of harmonic frequency to used for THD calculation, 0 tells the function to use all possible harmonics found in the spectrum
     
     Result
     ------  
@@ -276,25 +279,25 @@ def get_total_harmonic_distortion(spec_data: ss.SciStream, channel_index: int =
 def get_noise_floor(spec_data: ss.SciStream, channel_index: int = 0, one_over_f_edge_frq: float = 0.0, level_of_percentile: float = 50.0, res_noise_floor_spec: ss.SciStream = None) -> float:
     """ determine the noise floor of a spectrum.
     
-    With the level_of_percentie one can define the amount of spike and noise hills to be suppressed.
+    With the level_of_percentile one can define the amount of spike and noise hills to be suppressed.
     With a value of 50 in most cases the background noise is returned. 
     With 100 maximal value found in the spectrum is returned
     With 80-95 small spikes (50Hz or so) can be ignored but real unexpected noise increase is detected
 
-    Can be nicely combined with the function "create_compress_log_spectrum_mean()" to improve result
+    Can be nicely combined with the function "calc_compressed_spectrum()" to improve result
 
     Parameter
     ---------
     spec_data: SciStream
         The data source 
     channel_index: int
-        The data source  channel to analyse
+        The data source  channel to analyze
     one_over_f_edge_frq:  optional
         if defined compensate for 1/f noise increase below edge frequency. Defined in [Hz]. 
     level_of_percentile:  optional
-        defines the amount of data to be inside the noise_level. Usefull to compensate for spikes. Has to be from 1-100 [%]. 
+        defines the amount of data to be inside the noise_level. Useful to compensate for spikes. Has to be from 1-100 [%]. 
     res_noise_floor_spec: optional
-        if defined the used spectrum for noise_floor calculation is returned. Usefull to check for 1/f compensation
+        if defined the used spectrum for noise_floor calculation is returned. Useful to check for 1/f compensation
     
     Result
     ------  
@@ -323,7 +326,7 @@ def get_noise_floor(spec_data: ss.SciStream, channel_index: int = 0, one_over_f_
         res_noise_floor_spec.x.value = spec_data.x.value
     return noise_floor
 
-def get_amplitude(spec_data: ss.SciStream, channel_index: int = 0, frq: float = 0.0):
+def get_amplitude(spec_data: ss.SciStream, channel_index: int = 0, frq: float = 0.0) -> tuple[float, int]:
     """ returns the amplitude value of a specified frequency
         The amplitude value of the closest frequency found in the array is returned         
     
@@ -332,7 +335,7 @@ def get_amplitude(spec_data: ss.SciStream, channel_index: int = 0, frq: float =
     spec_data: SciStream
         The data source 
     channel_index: int
-        The data source  channel to analyse
+        The data source  channel to analyze
     frq : float
         the frequency of interest in [Hz]
 
@@ -355,3 +358,81 @@ def get_amplitude(spec_data: ss.SciStream, channel_index: int = 0, frq: float =
     else:
         amp = 0.0
     return (amp, found_index)
+
+def calc_signal_integral_of_frq_band(spec_data: ss.SciStream, start_frq: float, end_frq:float, spectral_density=False) -> float:
+    """ calculates the area of data in a specified frequency band
+
+    Parameters
+    ----------
+        spec_data: SciStream:
+             with frequency data in x channel and signal data in channel 0
+        start_frq, end_frq: float
+            defines the start and end frequency of the desired frequency band
+        spectral_density: bool
+            if true, the amplitude data are assumed to have unit [1/sqrt(Hz)]
+    
+    Result
+    ------
+        amp_integral: float
+            amplitude area from start_frq to end_frq in [amp_unit]
+    Exception
+    ---------
+        ValueError: 
+            In case the start or end_frq are not found in provided spec_data stream this exception is thrown
+    """
+    amp_integral = 0.0
+    try:
+        start_index: int = np.where(spec_data.x.value >= start_frq)[0][0]
+        end_index: int = np.where(spec_data.x.value >= end_frq)[0][0]
+    except:
+        raise ValueError(f"Start or End value not found in spec_data.x stream: start_frq={start_frq}, end_frq={end_frq}")
+    else:
+        for i in range(start_index, end_index):
+            current_value = spec_data.channels[0].value[i]
+            current_frq_band = spec_data.x.value[i+1] - spec_data.x.value[i]
+            if spectral_density:
+                current_value = current_value*current_value
+            amp_integral += current_value*current_frq_band
+    if spectral_density:
+        amp_integral = np.sqrt(amp_integral)
+    return amp_integral
+
+def calc_signal_integral_versus_upper_bandwidth(spec_data: ss.SciStream, start_frq: float, end_frq:float, spectral_density=False) -> ss.SciStream:
+    """ calculates an array of signal amplitudes versus frequency upper bound with fix start frequency
+        It creates the result array of amplitude integrals by sweeping from start_frq to end_frq and calculates for each step the signal integral.
+
+    Parameters
+    ----------
+        spec_data: SciStream:
+             with frequency data in x channel and signal data in channel 0
+        start_frq, end_frq: float
+            defines the start and end frequency of the desired frequency band
+        spectral_density: bool
+            if true, the amplitude data are assumed to have unit [1/sqrt(Hz)]
+    
+    Result
+    ------
+        SciStream: 
+            amplitude array of signal amplitude versus frequency upper bound with fix start frequency
+    Exception
+    ---------
+        ValueError: 
+            In case the start or end_frq are not found in provided spec_data stream this exception is thrown
+    """
+    result = ss.SciStream()
+    try:
+        start_index: int = np.where(spec_data.x.value >= start_frq)[0][0]
+        end_index: int = np.where(spec_data.x.value >= end_frq)[0][0]
+    except:
+        raise ValueError(f"Start or End value not found in spec_data.x stream: start_frq={start_frq}, end_frq={end_frq}")
+    else:
+        integral_value_array = np.zeros(end_index - start_index) 
+        integral_frq_array = spec_data.x.value[start_index:end_index]
+
+        for i in range(len(integral_value_array)):
+            integral_frq_array[i] = spec_data.x.value[start_index + i]
+            integral_value_array[i] = calc_signal_integral_of_frq_band(spec_data, start_frq, integral_frq_array[i], spectral_density)
+    
+        result = ss.SciStream((integral_frq_array, integral_value_array), x_unit=spec_data.x.unit)
+        result.set_channel_unit(0, spec_data.get_channel_unit(0).removesuffix(get_spectral_density_unit()))
+    return result
\ No newline at end of file
